@@ -10,8 +10,7 @@
 #include "utils/Helpers.hpp"
 #include "utils/assertion.hpp"
 
-namespace precice {
-namespace acceleration {
+namespace precice::acceleration {
 
 ConstantRelaxationAcceleration::ConstantRelaxationAcceleration(
     double           relaxation,
@@ -30,19 +29,10 @@ void ConstantRelaxationAcceleration::initialize(const DataMap &cplData)
   checkDataIDs(cplData);
 }
 
-void ConstantRelaxationAcceleration::performAcceleration(const DataMap &cplData)
+void ConstantRelaxationAcceleration::performAcceleration(DataMap &cplData, double windowStart, double windowEnd)
 {
   PRECICE_TRACE();
-  double omega         = _relaxation;
-  double oneMinusOmega = 1.0 - omega;
-  for (const DataMap::value_type &pair : cplData) {
-    auto &      values    = pair.second->values();
-    const auto &oldValues = pair.second->previousIteration();
-    values *= omega;
-    values += oldValues * oneMinusOmega;
-    PRECICE_DEBUG("pp values {}", values);
-  }
+  applyRelaxation(_relaxation, cplData, windowStart);
 }
 
-} // namespace acceleration
-} // namespace precice
+} // namespace precice::acceleration
