@@ -7,9 +7,7 @@
 #include "acceleration/impl/Preconditioner.hpp"
 #include "logging/Logger.hpp"
 
-namespace precice {
-namespace acceleration {
-namespace impl {
+namespace precice::acceleration::impl {
 
 /// Preconditioner that uses the constant user-defined factors to scale the quasi-Newton system.
 class ConstantPreconditioner : public Preconditioner {
@@ -19,9 +17,9 @@ public:
   /**
    * @brief Destructor, empty.
    */
-  virtual ~ConstantPreconditioner() {}
+  ~ConstantPreconditioner() override = default;
 
-  virtual void initialize(std::vector<size_t> &svs);
+  void initialize(std::vector<size_t> &svs) override;
 
 private:
   /**
@@ -29,7 +27,7 @@ private:
    *
    * @param[in] timeWindowComplete True if this FSI iteration also completed a time window
    */
-  virtual void _update_(bool timeWindowComplete, const Eigen::VectorXd &oldValues, const Eigen::VectorXd &res);
+  void _update_(bool timeWindowComplete, const Eigen::VectorXd &oldValues, const Eigen::VectorXd &res) override;
 
   logging::Logger _log{"acceleration::ConstantPreconditioner"};
 
@@ -37,6 +35,4 @@ private:
   std::vector<double> _factors;
 };
 
-} // namespace impl
-} // namespace acceleration
-} // namespace precice
+} // namespace precice::acceleration::impl
